#
# spec file for package operator-sdk
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           operator-sdk
Version:        1.35.0
Release:        1.1
Summary:        CLI for installing the Operator Lifecycle Manager
License:        Apache-2.0
URL:            https://github.com/operator-framework/operator-sdk
Source:         operator-sdk-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.19

%description
This project is a component of the Operator Framework, an open source toolkit to manage Kubernetes native applications, called Operators, in an effective, automated, and scalable way. Read more in the introduction blog post.

Operators make it easy to manage complex stateful applications on top of Kubernetes. However writing an Operator today can be difficult because of challenges such as using low level APIs, writing boilerplate, and a lack of modularity which leads to duplication.

The Operator SDK is a framework that uses the controller-runtime library to make writing operators easier by providing:

* High level APIs and abstractions to write the operational logic more intuitively
* Tools for scaffolding and code generation to bootstrap a new project fast
* Extensions to cover common Operator use cases

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
export K8S_VERSION=$(awk '/^export K8S_VERSION/ {print $4}' Makefile)
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-X github.com/operator-framework/operator-sdk/internal/version.Version=%{version} \
   -X github.com/operator-framework/operator-sdk/internal/version.GitVersion=v%{version} \
   -X github.com/operator-framework/operator-sdk/internal/version.GitCommit=v%{version} \
   -X github.com/operator-framework/operator-sdk/internal/version.ImageVersion=v%{version} \
   -X github.com/operator-framework/operator-sdk/internal/version.KubernetesVersion=v${K8S_VERSION}" \
   -o bin/operator-sdk ./cmd/operator-sdk

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh_completion.d/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%dir %{_datarootdir}/fish
%dir %{_datarootdir}/fish/vendor_completions.d
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%defattr(-,root,root)
%dir %{_datarootdir}/zsh_completion.d/
%{_datarootdir}/zsh_completion.d/_%{name}

%changelog
* Wed Jun 19 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.35.0:
  * Release v1.35.0 (#6775)
  * updating ansible plugin version to latest (#6773)
  * (helm/v1): fix role.yaml init scaffolding (#6769)
  * Fix documentation link issues: (#6766)
  * Update ubi-minimal to version 8.10 in all Dockerfiles to fix
    critical security vulnerabilities (#6764)
  * Update quickstart.md (#6732)
  * Bump ansible operator plugin to v1.34.2 (#6749)
  * Change DefaultIndexImage to UBI (#6726)
  * update Designing Lean Operators docs to use new Kubebuilder
    cache config options (#6743)
  * update cncf-maintainers (#6741)
  * Bump actions/setup-go from 4 to 5 (#6638)
  * docs: correct spelling of Operator scope (#6728)
  * Add OchiengEd to sdk-approvers (#6735)
  * Change docs to reflect updated controller runtime options for
    caching select namespaces (#6719)
  * bumping docker and oras (since docker types changed location)
    (#6720)
  * chore: fix some comments (#6717)
  * feat: support helm dryrun=server (#6691)
  * add acornett21 to sdk-approves list (#6711)
  * Release v1.34.0 (#6688)
* Sat May 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.34.2:
  * Release v1.34.2 (#6751)
  * No changes for this release!
* Fri Mar 15 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.34.1:
  * (helm/v1) Fix an issue that multi-arch images cannot be built
    from the project Makefile. (#6661
    <https://github.com/operator-framework/operator-sdk/pull/6661>)
* Fri Mar 15 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.34.0:
  * Bump ansible operator plugin version to 1.34.1 (#6685)
  * docs: add note about chainsaw (#6675)
  * rapid reset remediation (#6664)
  * Bump go-git (#6663)
  * fix: fix an issue that multi-arch images cannot be built from
    the project makefile (#6661)
  * refactor: change './bin' to 'LOCALBIN' (#6655)
  * fix: migrate apis directory to api per standard (#6646)
* Tue Jan 30 2024 andrea.manzini@suse.com
- Update to version 1.33.0:
  * Bump supported Kubernetes version to 1.27
  * Breaking change: (go/v4-alpha): go/v4 is now stable and is the
    default version used when scaffolding a Go based operator.
  * Breaking change: (kustomize/v2-alpha): kustomize/v2 is now
    stable and is the default version used in the plugin chain when
    using go/v4, ansible/v1, helm/v1, and hybrid/v1-alpha plugins.
  * Updated the supported OLM versions to 0.24.0, 0.25.0, and
    0.26.0.
  * (helm/v1): Deprecate the --config flag due to the
    controller-runtime ComponentConfig package being deprecated
    with the planned removal of support for loading manager options
    from a file.
  * operator-sdk olm install: fix a bug where the retry logic would
    not retry until the the command's timeout was reached,
    resulting in early exiting of the command before the specified
    timeout was reached.
* Sat Oct  7 2023 kastl@b1-systems.de
- Update to version 1.32.0:
  * Release v1.32.0 (#6593)
  * Updated API to inherit updated multi-arch validator that scans
    for node affinity. (#6592)
  * Add missing "controller-tools" update instructions to the
    v1.25.0 migration guide (#6525) (#6526)
  * helm-operator: reduce cache memory footprint (#6377)
  * (refactor): switch the ansible plugin to use
    github.com/operator-framework/ansible-operator-plugins, remove
    ansible code (#6583)
  * Bump docker/setup-buildx-action from 2 to 3 (#6568)
  * Allow users to add annotation to set configure rollback (#6546)
* Thu Sep 14 2023 Johannes Kastl <kastl@b1-systems.de>
- new package operator-sdk: SDK for building Kubernetes
  applications. Provides high level APIs, useful abstractions, and
  project scaffolding.
